pub struct Rect {
pub position: Position,
pub size: Size,
}Expand description
A rectangle defined by position and size.
Fields
position: PositionTop-left position.
size: SizeDimensions.
Implementations
Sourceimpl Rect
impl Rect
Sourcepub const fn contains(self, pos: Position) -> bool
pub const fn contains(self, pos: Position) -> bool
Returns true if the point is inside this rectangle.
Sourcepub const fn intersects(self, other: &Rect) -> bool
pub const fn intersects(self, other: &Rect) -> bool
Returns true if two rectangles overlap.
Sourcepub fn intersection(self, other: &Rect) -> Option<Rect>
pub fn intersection(self, other: &Rect) -> Option<Rect>
Returns the intersection of two rectangles, or None if they don’t overlap.