Layout

Struct Layout 

pub struct Layout;
Layout utilities for splitting terminal areas.

Implementations

Source

impl Layout

pub fn split( area: Rect, direction: Direction, constraints: &[Constraint], ) -> Vec<Rect>

Split an area into segments along the given direction using constraints.

Returns a Vec<Rect> with one rect per constraint.

pub fn dock(area: Rect, dock: Dock, size: u16) -> (Rect, Rect)

Dock a region to one edge of the area.

Returns (docked_rect, remaining_rect).