pub struct AdaptiveDhtConfig {
pub block_threshold: f64,
}Expand description
Configuration for the AdaptiveDHT layer
Fields
block_threshold: f64Trust score below which a peer is evicted from the routing table and blocked from sending DHT messages or being re-added to the RT. Eviction is immediate when a peer’s score crosses this threshold. Default: 0.15
Implementations