WrapLine

Struct WrapLine 

pub struct WrapLine {
    pub text: String,
    pub logical_line: usize,
    pub start_col: usize,
}
A single visual line resulting from soft-wrapping a logical line.

Fields

text: String

The text content of this visual line.

logical_line: usize

The index of the logical line this visual line belongs to.

start_col: usize

The character offset within the logical line where this visual line starts.