NodeIdentity

Struct NodeIdentity 

pub struct NodeIdentity { /* private fields */ }
Core node identity with cryptographic keys

Debug is manually implemented to redact secret key material.

Implementations

Source

impl NodeIdentity

pub fn generate() -> Result<Self, P2PError>

Generate new identity

pub fn from_seed(seed: &[u8; 32]) -> Result<Self, P2PError>

Generate from seed (deterministic)

pub fn peer_id(&self) -> &PeerId

Get peer ID

pub fn public_key(&self) -> &MlDsaPublicKey

Get public key

pub fn secret_key_bytes(&self) -> &[u8]

Get secret key bytes (for raw key authentication)

pub fn sign(&self, message: &[u8]) -> Result<MlDsaSignature, P2PError>

Sign a message

pub fn verify( &self, message: &[u8], signature: &MlDsaSignature, ) -> Result<bool, P2PError>

Verify a signature

pub fn to_public(&self) -> PublicNodeIdentity

Create a public version of this identity (safe to clone)

Source

impl NodeIdentity

pub fn from_secret_key(_secret_key: MlDsaSecretKey) -> Result<Self, P2PError>

Create an identity from an existing secret key Note: Currently not supported as saorsa-transport doesn’t provide public key derivation from secret key This would require storing both keys together

Source

impl NodeIdentity

pub async fn save_to_file(&self, path: &Path) -> Result<(), P2PError>

Save identity to a JSON file (async)

pub async fn load_from_file(path: &Path) -> Result<Self, P2PError>

Load identity from a JSON file (async)

Source

impl NodeIdentity

pub fn export(&self) -> IdentityData

Export identity for persistence

pub fn import(data: &IdentityData) -> Result<Self, P2PError>

Import identity from persisted data