pub fn batch_changes(changes: &[CellChange]) -> Vec<DeltaBatch>Expand description
Computes delta batches from cell changes, grouping consecutive same-row cells.
Two changes are grouped into the same batch when they are on the same row and the second change’s x position equals the first change’s x plus the first change’s cell width (i.e., they are visually adjacent). Continuation cells (width 0) are skipped.